@@ -15,10 +15,12 @@ __all__ = [
     "TranslationVariableLanguages",
     "Video",
     "Pdf",
+    "Nifti",
 ]
 from .audio import Audio
 from .features import Array2D, Array3D, Array4D, Array5D, ClassLabel, Features, LargeList, List, Sequence, Value
 from .image import Image
+from .nifti import Nifti
 from .pdf import Pdf
 from .translation import Translation, TranslationVariableLanguages
 from .video import Video
